#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
#include <stdio.h>
#include <stdlib.h>
#include <X11/X.h>
#include <X11/xpm.h>
#include <X11/Xlib.h>
#include <X11/Xlocale.h>
#include <unistd.h>
#include <string.h>

#include "wmgeneral.h"
#include "uim-helper-wm.h"
#include "pixmaps.h"

#include <uim/uim.h>
#include <uim/uim-helper.h>
#include <uim/uim-im-switcher.h>

#include <iconv.h>

#ifdef MEMCHECK
#include <memcheck.h>
#endif /* MEMCHECK */


/* Prototypes */
static void print_usage(void);
static void ParseCMDLine(int argc, char *argv[]);

#define DEFAULT_FONT "-shinonome-gothic-medium-r-normal--12-*-*-*-*-*"
#define SUBSTITUTE_FONT "-misc-fixed-medium-r-normal--12-*-*-*-*-*"



static void print_usage(void)
{
	printf("\nwmuim version: %s\n", VERSION);
	printf("\nTODO: Write This.\n\n");
}

static void ParseCMDLine(int argc, char *argv[])
{
	int	i;

	for (i = 1; i < argc; i++) {
		if (!strcmp(argv[i], "-display")) {
			++i; /* -display is used in wmgeneral */
			/*} else if (!strcmp(argv[i], "-option_with_param")) {
			  strcpy(param, argv[++i]);
			  } else if (!strcmp(argv[i], "-option_wo_param")) {
			  param = 1;*/
		} else if (strcmp(argv[i], "-d") == 0) {
			/* debug mode */
		} else {
			print_usage();
			exit(1);
		}
	}
}


int main(int argc, char **argv)
{
	XEvent	event;

	char **miss, *def;
	int n_miss; 
	int white, black;
	int tmpButtonStatus;
	int uim_fd;

	ParseCMDLine(argc, argv);

	setlocale(LC_ALL, "");

	openXwindow(argc, argv, xpm_master, xpm_mask_bits, xpm_mask_width, xpm_mask_height);

	GetXPM(&text_pixmap, text_xpm);

	fontset = XCreateFontSet(display, 
				 DEFAULT_FONT
				 , &miss, &n_miss, &def); 
	if (fontset == NULL)
		fontset = XCreateFontSet(display, 
					 SUBSTITUTE_FONT
					 , &miss, &n_miss, &def); 
	white = WhitePixel(display, 0); 
	black = BlackPixel(display, 0); 
	XSetForeground(display, NormalGC, white);
	XSetBackground(display, NormalGC, black);

/*
  font_uni = XLoadQueryFont(display, FONT_NAME_UNI);
  XSetFont(display, NormalGC, font_uni->fid);
*/
#ifdef DEBUG
	printf("%s\n", XBaseFontNameListOfFontSet(fontset));
	printf("%s\n", XLocaleOfFontSet(fontset));
#endif /* DEBUG */

	wmuim_set_mouse_region();

	uim_fd = wmuim_init();
	/* Loop Forever */
	while (1) {
		wmuim_periodic_function();
/*	  printf("current_im_name :%s\n", uim_get_current_im_name(uc));*/
		/* Process any pending X events. */
		while (XPending(display)) {
			XNextEvent(display, &event);
			switch (event.type) {
			case Expose:
				RedrawWindow();
				break;
			case ButtonPress:
				tmpButtonStatus = 
					CheckMouseRegion(event.xbutton.x, event.xbutton.y);
				printf ("ButtonPress %d(%d, %d)\n", tmpButtonStatus,
					event.xbutton.x, event.xbutton.y);
				wmuim_button_press(tmpButtonStatus);
				break;
			case ButtonRelease:
				break;
			}
		}
		usleep(10000);
	}

	/* we should never get here */
	return (0);
}


/*

prop_label_update
charset=UTF-8
S       直接入力


prop_list_update
charset=UTF-8
branch  S       直接入力
leaf    え      ひらがな        ひらがなモード  prop_skk_hiragana
leaf    エ      カタカナ        カタカナモード  prop_skk_katakana
leaf    エ       半角カタカナ    半角カタカナモード      prop_skk_hankana
leaf    S       直接入力        直接入力モード  prop_skk_latin  *
leaf    Ｓ      全角英数        全角英数モード  prop_skk_wide_latin


focus_out


focus_in

*/

